.. _Tools:

Tools functions
=============== 

Below is a list of the general tools developed for the MJOLNIR software package.



.. currentmodule:: _tools



.. autosummary::
   :nosignatures:

   KwargChecker
   my_timer_N
   beautifyArgs
   binEdges
   fileListGenerator
   RoundBinning
   invert
   minMax
   unitVector
   rotMatrix
   Rot
   clockwiseangle_and_distance
   vectorAngle
   generateLabel
   writeToSpinWFile
   

Functions in the _tools module
------------------------------

.. automodule:: _tools
    :members:
